diff -pruN 1.3.0-1/debian/changelog 1.4.0-1/debian/changelog
--- 1.3.0-1/debian/changelog	2023-08-28 23:45:16.000000000 +0000
+++ 1.4.0-1/debian/changelog	2024-04-07 00:26:02.000000000 +0000
@@ -1,3 +1,10 @@
+gnome-pass-search-provider (1.4.0-1) unstable; urgency=medium
+
+  * QA upload.
+  * New upstream release.
+
+ -- Boyuan Yang <byang@debian.org>  Sat, 06 Apr 2024 20:26:02 -0400
+
 gnome-pass-search-provider (1.3.0-1) unstable; urgency=medium
 
   * QA upload.
diff -pruN 1.3.0-1/gnome-pass-search-provider.py 1.4.0-1/gnome-pass-search-provider.py
--- 1.3.0-1/gnome-pass-search-provider.py	2022-10-28 01:14:13.000000000 +0000
+++ 1.4.0-1/gnome-pass-search-provider.py	2024-03-03 10:53:09.000000000 +0000
@@ -70,10 +70,15 @@ class SearchPassService(dbus.service.Obj
         self.disable_notifications = (
             getenv("DISABLE_NOTIFICATIONS", "false").lower() == "true"
         )
+        # For checking if the database is unlocked yet:
+        self.database_unlocked = True
 
     @dbus.service.method(in_signature="sasu", **sbn)
     def ActivateResult(self, id, terms, timestamp):
-        self.send_password_to_clipboard(id)
+        if self.database_unlocked:
+            self.send_password_to_clipboard(id)
+        else:
+            self.unlock_database()
 
     @dbus.service.method(in_signature="as", out_signature="as", **sbn)
     def GetInitialResultSet(self, terms):
@@ -104,26 +109,39 @@ class SearchPassService(dbus.service.Obj
     def LaunchSearch(self, terms, timestamp):
         pass
 
+    def unlock_database(self):
+        if self.password_mode == "bw":
+            subprocess.run([self.password_executable, "unlock"])
+
     def get_bw_result_set(self, terms):
-        if terms[0].startswith(":"):
-            field = terms[0][1:]
-            terms = terms[1:]
+        self.database_unlocked = not bool(subprocess.run(
+            [self.password_executable, "unlocked"]
+            ).returncode)
+
+        if not self.database_unlocked:
+            results = [f"Unlock {self.password_executable}"]
+
         else:
-            field = None
-        name = "".join(terms)
+            if terms[0].startswith(":"):
+                field = terms[0][1:]
+                terms = terms[1:]
+            else:
+                field = None
+            name = "".join(terms)
 
-        password_list = subprocess.check_output(
-            [self.password_executable, "list"], universal_newlines=True
-        ).split("\n")[:-1]
+            password_list = subprocess.check_output(
+                [self.password_executable, "list"], universal_newlines=True
+            ).split("\n")[:-1]
+
+            results = [
+                e[0]
+                for e in process.extract(
+                    name, password_list, limit=5, scorer=fuzz.partial_ratio
+                )
+            ]
+            if field is not None:
+                results = [f":{field} {r}" for r in results]
 
-        results = [
-            e[0]
-            for e in process.extract(
-                name, password_list, limit=5, scorer=fuzz.partial_ratio
-            )
-        ]
-        if field is not None:
-            results = [f":{field} {r}" for r in results]
         return results
 
     def get_pass_result_set(self, terms):
@@ -161,39 +179,43 @@ class SearchPassService(dbus.service.Obj
             results = [f":{field} {r}" for r in results]
         return results
 
-    def send_password_to_gpaste(self, base_args, name, field=None):
-        gpaste = self.session_bus.get_object(
-            "org.gnome.GPaste.Daemon", "/org/gnome/GPaste"
-        )
-
-        output = subprocess.check_output(base_args + [name], universal_newlines=True)
+    def get_value_from_output(self, output, field=None):
         if field is not None:
             match = re.search(
                 rf"^{field}:\s*(?P<value>.+?)$", output, flags=re.I | re.M
             )
             if match:
-                password = match.group("value")
+                value = match.group("value")
             else:
-                raise RuntimeError(f"The field {field} was not found in the pass file.")
+                raise RuntimeError(f"The field {field} was not found in the password entry.")
         else:
-            password = output.split("\n", 1)[0]
+            value = output.split("\n", 1)[0]
+        return value
+
+    def send_password_to_gpaste(self, base_args, name, field=None):
+        gpaste = self.session_bus.get_object(
+            "org.gnome.GPaste.Daemon", "/org/gnome/GPaste"
+        )
+
+        output = subprocess.check_output(base_args + [name], universal_newlines=True)
+        value = self.get_value_from_output(output, field)
         try:
-            gpaste.AddPassword(name, password, dbus_interface="org.gnome.GPaste1")
+            gpaste.AddPassword(name, value, dbus_interface="org.gnome.GPaste1")
         except dbus.DBusException:
-            gpaste.AddPassword(name, password, dbus_interface="org.gnome.GPaste2")
+            gpaste.AddPassword(name, value, dbus_interface="org.gnome.GPaste2")
 
     def send_password_to_native_clipboard(self, base_args, name, field=None):
-        if field is not None:
-            raise RuntimeError("This feature requires GPaste.")
-
         if self.password_mode == "bw":
-            p1 = subprocess.Popen(base_args + [name], stdout=subprocess.PIPE)
-            p2 = subprocess.run(self.clipboard_executable, stdin=p1.stdout)
-            if p1.returncode or p2.returncode:
+            output = subprocess.check_output(base_args + [name], universal_newlines=True)
+            value = self.get_value_from_output(output, field)
+            p1 = subprocess.run(self.clipboard_executable, input=value, text=True)
+            if p1.returncode:
                 raise RuntimeError(
-                    f"Error while running rbw: got return codes: {p1.returncode} {p2.returncode}."
+                    f"Error while running copying to clipboard: got return code: {p1.returncode}."
                 )
         else:
+            if field is not None:
+                raise RuntimeError("This feature requires GPaste.")
             result = subprocess.run(base_args + ["-c", name])
             if result.returncode:
                 raise RuntimeError(
@@ -210,7 +232,10 @@ class SearchPassService(dbus.service.Obj
         if self.password_mode == "bw":
             base_args = [self.password_executable, "get", "--full"]
         elif name.startswith("otp "):
-            base_args = [self.password_executable, "otp", "code"]
+            if self.password_executable == "gopass":
+                base_args = [self.password_executable, "otp", "-o"]
+            else:
+                base_args = [self.password_executable, "otp", "code"]
             name = name[4:]
             field = None
         else:
